==> oer-0.0.1-20190731.023331-5-sources.jar: com/xdja/pki/itsca/oer/app/EnrollmentCertRespBuilder.java <==
package com.xdja.pki.itsca.oer.app;

import com.xdja.pki.itsca.oer.asn1.SecuredMessage;
import com.xdja.pki.itsca.oer.asn1.Certificate;

import java.security.PrivateKey;

/***
 *EnrollmentCertResp ::= SecureMessage(WITH COMPONENTS { ...,
 * 	version(2),
 * 	payload(WITH COMPONENTS { ...,
 * 		signedData(WITH COMPONENTS { ...,
 * 			signer(WITH COMPONENTS {
 * 				certificate(SequenceOfCertificate(SIZE(1)))
 *                        }),
 * 			tbs(WITH COMPONENTS { ...,
 * 				headerInfo(WITH COMPONENTS { ...,
 * 					itsAid(40962),
 * 					hashAlg PRESENT,
 * 					genTime PRESENT,
 * 					expiryTime ABSENT,
 * 					digest ABSENT,
 * 					encKey ABSENT
 *                }),
 * 				data(CONTAINING EnrollmentCertRespData),
 * 				extHash  ABSENT
 *            })* 		})
 *    })
 * })
 *
 * EnrollmentCertRespData ::= SecureMessage(WITH COMPONENTS { ...,
 * 	version(2),
 * 	payload(WITH COMPONENTS { ...,
 * 		encData(WITH COMPONENTS { ...,
 * 			recipients(SequenceOfRecipientInfo (SIZE(1)) (CONSTRAINED BY {
 * 				RecipientInfo(WITH COMPONENTS {
 * 					signedDataRecipInfo
 *                })* 			}        ))
 *    })
 *    })
 * })
 */
public class EnrollmentCertRespBuilder extends SecuredMessageBuild {

    /**
     * @param privateKey  私钥签名使用
     * @param respData    安全信息内部包的安全信息
     * @param certificate 签名者证书
     * @return EnrollmentCertRequest   F.2.1　注册证书请求数据格式
     */
    public SecuredMessage build(PrivateKey privateKey, SecuredMessage respData, Certificate certificate) throws Exception {
        return super.builder(privateKey, respData, 40962, certificate);
    }
}

==> oer-0.0.2-20190820.092159-13-sources.jar: com/xdja/pki/itsca/oer/app/EnrollmentCertRespBuilder.java <==
package com.xdja.pki.itsca.oer.app;

import com.xdja.pki.itsca.oer.asn1.SecuredMessage;
import com.xdja.pki.itsca.oer.asn1.Certificate;

import java.security.PrivateKey;

/***
 *EnrollmentCertResp ::= SecureMessage(WITH COMPONENTS { ...,
 * 	version(2),
 * 	payload(WITH COMPONENTS { ...,
 * 		signedData(WITH COMPONENTS { ...,
 * 			signer(WITH COMPONENTS {
 * 				certificate(SequenceOfCertificate(SIZE(1)))
 *                        }),
 * 			tbs(WITH COMPONENTS { ...,
 * 				headerInfo(WITH COMPONENTS { ...,
 * 					itsAid(40962),
 * 					hashAlg PRESENT,
 * 					genTime PRESENT,
 * 					expiryTime ABSENT,
 * 					digest ABSENT,
 * 					encKey ABSENT
 *                }),
 * 				data(CONTAINING EnrollmentCertRespData),
 * 				extHash  ABSENT
 *            })* 		})
 *    })
 * })
 *
 * EnrollmentCertRespData ::= SecureMessage(WITH COMPONENTS { ...,
 * 	version(2),
 * 	payload(WITH COMPONENTS { ...,
 * 		encData(WITH COMPONENTS { ...,
 * 			recipients(SequenceOfRecipientInfo (SIZE(1)) (CONSTRAINED BY {
 * 				RecipientInfo(WITH COMPONENTS {
 * 					signedDataRecipInfo
 *                })* 			}        ))
 *    })
 *    })
 * })
 */
public class EnrollmentCertRespBuilder extends SecuredMessageBuild {

    /**
     * @param privateKey  私钥签名使用
     * @param respData    安全信息内部包的安全信息
     * @param certificate 签名者证书
     * @return EnrollmentCertRequest   F.2.1　注册证书请求数据格式
     */
    public SecuredMessage build(PrivateKey privateKey, SecuredMessage respData, Certificate certificate) throws Exception {
        return super.build(privateKey, respData, 40962, certificate);
    }
}
